<?php
/**
 * @file
 * Implementation of OpenLayers behavior.
 */

/**
 * Attribution Behavior
 */
class openlayers_behavior_rb_centeredcluster extends openlayers_behavior {
  /**
   * Provide initial values for options.
   */
  function options_init() {
    return array(
      'layers' => array(),
    );
  }

  /**
   * Form defintion for per map customizations.
   */
  function options_form($defaults = array()) {
    $form = parent::options_form(array());

    // Only prompt for vector layers.
    $vector_layers = array();
    foreach ($this->map['layers'] as $id => $name) {
      $layer = openlayers_layer_load($id);
      if (isset($layer->data['vector']) && $layer->data['vector'] == TRUE) {
        $vector_layers[$id] = $name;
      }
    }

    ksort($vector_layers);

    foreach ($vector_layers as $id => $name) {

      $layer = openlayers_layer_load($id);

      $form['layers'][$id] = array(
        '#type' => 'fieldset',
        '#title' => t('Options for layer @layer', array('@layer' => $name)),
        '#collapsible' => TRUE,
        '#collapsed' => FALSE,
      );
      $form['layers'][$id]['layer'] = array(
        '#type' => 'checkbox',
        '#title' => t('Enable the cluster ?'),
        '#description' => t("If selected, the layer will be replaced by it's cluster.") .
          '<br/>(' . check_plain($layer->name) .
          ': ' . check_plain($layer->description) . ')',
        '#default_value' => !empty($defaults['layers'][$id]['layer']) ? 1 : FALSE,
      );
      $form['layers'][$id]['distance'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['distance'])) ?
          $defaults['layers'][$id]['distance'] : 20,
        '#size' => 5,
        '#title' => t('Distance'),
        '#description' => t('Pixel distance between features that should ' .
          'be considered a single cluster'),
      );
      $form['layers'][$id]['threshold'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['threshold'])) ?
          $defaults['layers'][$id]['threshold'] : NULL,
        '#size' => 5,
        '#title' => t('Threshold'),
        '#description' => t('Optional threshold below which original ' .
          'features will be added to the layer instead of clusters'),
      );
      $form['layers'][$id]['display_cluster_numbers'] = array(
        '#type' => 'checkbox',
        '#title' => t('Display numbers in clusters?'),
        '#default_value' => isset($defaults['layers'][$id]['display_cluster_numbers']) ? $defaults['layers'][$id]['display_cluster_numbers'] : TRUE
      );
      $form['layers'][$id]['middle_lower_bound'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['middle_lower_bound'])) ?
          $defaults['layers'][$id]['middle_lower_bound'] : 15,
        '#size' => 5,
        '#title' => t('Middle lower bound'),
        '#description' => t(''),
      );
      $form['layers'][$id]['middle_upper_bound'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['middle_upper_bound'])) ?
          $defaults['layers'][$id]['middle_upper_bound'] : 50,
        '#size' => 5,
        '#title' => t('Middle upper bound'),
        '#description' => t(''),
      );
      $form['layers'][$id]['low_color'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['low_color'])) ?
          $defaults['layers'][$id]['low_color'] : 'rgb(181, 226, 140)',
        '#size' => 5,
        '#title' => t('Low color'),
        '#description' => t(''),
      );
      $form['layers'][$id]['middle_color'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['middle_color'])) ?
          $defaults['layers'][$id]['middle_color'] : 'rgb(241, 211, 87)',
        '#size' => 5,
        '#title' => t('Low color'),
        '#description' => t(''),
      );
      $form['layers'][$id]['high_color'] = array(
        '#type' => 'textfield',
        '#default_value' => (isset($defaults['layers'][$id]['high_color'])) ?
          $defaults['layers'][$id]['high_color'] : 'rgb(253, 156, 115)',
        '#size' => 5,
        '#title' => t('Low color'),
        '#description' => t(''),
      );

    }

    return $form;
  }

  function attached() {
    return array(
      'libraries_load' => array(
        'olrb'
      )
    );
  }


  /**
   * Render.
   */
  function render(&$map) {
    return $this->options;
  }
}
